@@ -4,10 +4,9 @@
 from datetime import timedelta, datetime
 from math import ceil
 from logging import getLogger
-from os import listdir
 from pathlib import Path
 
-from numpy import arange, asarray, empty, int64
+from numpy import arange, asarray, concatenate, empty, int64, zeros
 
 from .ioeeg import (Abf,
                     Edf,
@@ -24,6 +23,7 @@ from .ioeeg import (Abf,
                     OpenEphys,
                     Text,
                     BIDS,
+                    LyonRRI,
                     )
 from .ioeeg.bci2000 import _read_header_length
 from .datatype import ChanTime
@@ -90,7 +90,7 @@ def detect_format(filename):
             return EgiMff
         elif list(filename.glob('*.openephys')):
             return OpenEphys
-        elif '.txt' in [x[-4:] for x in listdir(filename)]:
+        elif list(filename.glob('*.txt')):
             return Text
         else:
             raise UnrecognizedFormat('Unrecognized format for directory ' +
@@ -130,9 +130,16 @@ def detect_format(filename):
                 return BlackRock
             elif file_header[:6] == b'MATLAB':  # we might need to read more
                 return FieldTrip
-            else:
-                raise UnrecognizedFormat('Unrecognized format for file ' +
-                                         str(filename))
+        
+        if filename.suffix.lower() == '.txt':
+            with filename.open('rt') as f:
+                first_line = f.readline()
+                if '.rr' in first_line[-4:]:
+                    return LyonRRI
+        
+        else:
+            raise UnrecognizedFormat('Unrecognized format for file ' +
+                                     str(filename))
 
 
 class Dataset:
@@ -265,7 +272,7 @@ class Dataset:
         return videos
 
     def read_data(self, chan=None, begtime=None, endtime=None, begsam=None,
-                  endsam=None):
+                  endsam=None, s_freq=None):
         """Read the data and creates a ChanTime instance
 
         Parameters
@@ -288,6 +295,8 @@ class Dataset:
             first sample (this sample will be included)
         endsam : int
             last sample (this sample will NOT be included)
+        s_freq : int
+            sampling frequency of the data
 
         Returns
         -------
@@ -307,12 +316,16 @@ class Dataset:
         """
         data = ChanTime()
         data.start_time = self.header['start_time']
-        data.s_freq = self.header['s_freq']
+        data.s_freq = s_freq = s_freq if s_freq else self.header['s_freq']
 
         if chan is None:
             chan = self.header['chan_name']
         if not (isinstance(chan, list) or isinstance(chan, tuple)):
             raise TypeError('Parameter "chan" should be a list')
+        add_ref = False
+        if '_REF' in chan:
+            add_ref = True
+            chan[:] = [x for x in chan if x != '_REF']
         idx_chan = [self.header['chan_name'].index(x) for x in chan]
 
         if begtime is None and begsam is None:
@@ -347,15 +360,20 @@ class Dataset:
         data.axis['time'] = empty(n_trl, dtype='O')
         data.data = empty(n_trl, dtype='O')
 
-        for i, one_begsam, one_endsam in zip(range(n_trl), begsam, endsam):
-            data.axis['chan'][i] = asarray(chan, dtype='U')
-            data.axis['time'][i] = (arange(one_begsam, one_endsam) /
-                                    self.header['s_freq'])
-
+        for i, one_begsam, one_endsam in zip(range(n_trl), begsam, endsam):            
             dataset = self.dataset
             lg.debug('begsam {0: 6}, endsam {1: 6}'.format(one_begsam,
                      one_endsam))
             dat = dataset.return_dat(idx_chan, one_begsam, one_endsam)
+            chan_in_dat = chan
+            
+            if add_ref:
+                zero_ref = zeros((1, one_endsam - one_begsam))
+                dat = concatenate((dat, zero_ref), axis=0)
+                chan_in_dat.append('_REF')
+            
             data.data[i] = dat
+            data.axis['chan'][i] = asarray(chan_in_dat, dtype='U')
+            data.axis['time'][i] = (arange(one_begsam, one_endsam) / s_freq)
 
         return data
