@@ -156,8 +156,14 @@ class Edf:
         self.phys_min = asarray(self.hdr['physical_min'])
         phys_range = asarray(self.hdr['physical_max']) - self.phys_min
         dig_range = asarray(self.hdr['digital_max']) - self.dig_min
-        assert all(phys_range > 0)
-        assert all(dig_range > 0)
+        if (phys_range < 0).any():
+            lg.warning('physical_min is higher than physical_max. Check whether the polarity of your recordings is correct')
+        if (dig_range < 0).any():
+            lg.warning('digital_min is higher than digital_max. Check whether the polarity of your recordings is correct')
+        if sum(self.dig_min) == 0:
+            lg.warning('digital_min is zero. Setting to -32767.')
+            self.dig_min = ones(self.dig_min.shape) * -32767.0
+            dig_range = 2 * 32767.0
         self.gain = phys_range / dig_range
 
         subj_id = self.hdr['subject_id']
@@ -270,7 +276,8 @@ class Edf:
         return markers
 
 
-def write_edf(data, filename, subj_id='X X X X', physical_max=1000):
+def write_edf(data, filename, subj_id='X X X X', physical_max=1000, 
+              physical_min=None):
     """Export data to FieldTrip.
 
     Parameters
@@ -305,7 +312,9 @@ def write_edf(data, filename, subj_id='X X X X', physical_max=1000):
     precision = physical_max / DIGITAL_MAX
     lg.info('Data exported to EDF will have precision ' + str(precision))
 
-    physical_min = -1 * physical_max
+    if physical_min is None:
+        physical_min = -1 * physical_max
+    
     dat = data.data[0] / physical_max * DIGITAL_MAX
     dat = dat.astype(EDF_FORMAT)
     dat[dat > DIGITAL_MAX] = DIGITAL_MAX
