@@ -6,10 +6,8 @@ use this package to transform to other classes. If you want to transform to
 basic elements, use the package "detect" for example.
 
 """
-from .analyze import (event_params, export_freq, export_freq_band, 
-                      export_event_params)
 from .filter import filter_, convolve
-from .select import (select, resample, get_times, _select_channels, fetch, 
+from .select import (select, resample, get_times, _select_channels, fetch,
                      Segments)
 from .frequency import frequency, timefrequency, band_power
 from .merge import concatenate
@@ -17,4 +15,5 @@ from .math import math, get_descriptives
 from .montage import montage
 from .peaks import peaks
 from .reject import rejectbadchan, remove_artf_evts
+from .analyze import export_freq, export_freq_band
 
