@@ -44,7 +44,7 @@ stdicon = QCommonStyle.standardIcon
 icon_path = join(dirname(realpath(__file__)), 'icons')
 oxy_path = join(icon_path, 'oxygen')
 
-ICON = {'application': join(icon_path, 'wonambi.jpg'),
+ICON = {'application': join(icon_path, 'wonambi.png'),
         'open_rec': join(oxy_path, 'document-open.png'),
         'page_prev': join(oxy_path, 'go-previous-view.png'),
         'page_next': join(oxy_path, 'go-next-view.png'),
@@ -266,11 +266,14 @@ class FormFloat(QLineEdit):
     widgets.
 
     """
-    def __init__(self, default=None):
+    def __init__(self, default=None, maxw=None):
         super().__init__('')
 
         if default is not None:
             self.set_value(default)
+            
+        if maxw is not None:
+            self.setMaximumWidth(maxw)
 
     def get_value(self, default=0):
         """Get float from widget.
